# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`nscd`](#nscd): Configures /etc/ncsd.conf and controls nscd service.
* [`nscd::config`](#nscd--config): == Class nscd::config Configures nscd.

#### Private Classes

* `nscd::install`: installs nscd
* `nscd::service`: controls nscd service

### Data types

* [`Nscd::Database`](#Nscd--Database): hash of configuration in nscd.conf
* [`Nscd::Database::Settings`](#Nscd--Database--Settings): all possible settings an nscd database can have

## Classes

### <a name="nscd"></a>`nscd`

nscd class.

Note for each database at least the `enable-cache` key
must be specified.

#### Examples

##### 

```puppet
class{'nscd':
  dbconfigs  => {
    'passwd' => {'enable-cache'         => true,
                 'maximum-time-to-live' => 100,
                 },
    'group' => {'enable-cache'         => true,
                'maximum-time-to-live' => 100,
               },

  }
```

#### Parameters

The following parameters are available in the `nscd` class:

* [`pkg_ensure`](#-nscd--pkg_ensure)
* [`service_ensure`](#-nscd--service_ensure)
* [`service_enable`](#-nscd--service_enable)
* [`threads`](#-nscd--threads)
* [`max_threads`](#-nscd--max_threads)
* [`paranoia`](#-nscd--paranoia)
* [`restart_interval`](#-nscd--restart_interval)
* [`user`](#-nscd--user)
* [`stat_user`](#-nscd--stat_user)
* [`debug_level`](#-nscd--debug_level)
* [`reload_count`](#-nscd--reload_count)
* [`logfile`](#-nscd--logfile)
* [`dbconfig`](#-nscd--dbconfig)

##### <a name="-nscd--pkg_ensure"></a>`pkg_ensure`

Data type: `Enum['present','absent','latest']`

state of nscd package.

Default value: `'present'`

##### <a name="-nscd--service_ensure"></a>`service_ensure`

Data type: `Boolean`

state of nscd service ensure

Default value: `true`

##### <a name="-nscd--service_enable"></a>`service_enable`

Data type: `Boolean`

state of nscd service enable

Default value: `true`

##### <a name="-nscd--threads"></a>`threads`

Data type: `Integer`

number of threads.

Default value: `5`

##### <a name="-nscd--max_threads"></a>`max_threads`

Data type: `Integer`

maximum number of threads.

Default value: `32`

##### <a name="-nscd--paranoia"></a>`paranoia`

Data type: `Boolean`

enable internal restart mode.

Default value: `false`

##### <a name="-nscd--restart_interval"></a>`restart_interval`

Data type: `Optional[Integer]`

nscd internal restart interval

Default value: `undef`

##### <a name="-nscd--user"></a>`user`

Data type: `String[1]`

specify which user should run nscd

Default value: `'root'`

##### <a name="-nscd--stat_user"></a>`stat_user`

Data type: `Optional[String[1]]`

which users can query statistics

Default value: `undef`

##### <a name="-nscd--debug_level"></a>`debug_level`

Data type: `Integer`

debug level

Default value: `0`

##### <a name="-nscd--reload_count"></a>`reload_count`

Data type: `Integer`

any many reload attempts to make

Default value: `5`

##### <a name="-nscd--logfile"></a>`logfile`

Data type: `Optional[Stdlib::UnixPath]`

specify a debug log file location.

Default value: `undef`

##### <a name="-nscd--dbconfig"></a>`dbconfig`

Data type: `Nscd::Database`

configuration for each of the passwd, group, hosts and service database.

### <a name="nscd--config"></a>`nscd::config`

== Class nscd::config
Configures nscd.

## Data types

### <a name="Nscd--Database"></a>`Nscd::Database`

hash of configuration in nscd.conf

Alias of

```puppet
Struct[{
    Optional['passwd']   => Nscd::Database::Settings,
    Optional['group']    => Nscd::Database::Settings,
    Optional['hosts']    => Nscd::Database::Settings,
    Optional['services'] => Nscd::Database::Settings,
    Optional['netgroup'] => Nscd::Database::Settings,
  }]
```

### <a name="Nscd--Database--Settings"></a>`Nscd::Database::Settings`

all possible settings an nscd database can have

Alias of

```puppet
Struct[{
    'enable-cache'                    => Boolean,
    Optional['positive-time-to-live'] => Integer,
    Optional['negative-time-to-live'] => Integer,
    Optional['suggested-size']        => Integer,
    Optional['check-files']           => Boolean,
    Optional['persistent']            => Boolean,
    Optional['shared']                => Boolean,
    Optional['max-db-size']           => Integer,
    Optional['auto-propagate']        => Boolean,
  }]
```

